@@ -952,12 +952,10 @@ class BackendBase(implements(BackendInterface)):
         we cannot rely on blobfuse mapping, and we know we have xtlib installed.
         '''
 
-        fn_stdout_aml = "azureml-logs/00_f5cca3f8f56b6f68d8499ecd4520d4a8-master-0_stdout.txt"
-        fn_stdout_aml = "azureml-logs/00_{}_stdout.txt"
-
+        #fn_stdout_aml = "azureml-logs/00_f5cca3f8f56b6f68d8499ecd4520d4a8-master-0_stdout.txt"
         # debug (ensure azureml-logs is present on ITP runs)
-        self.append(cmds, "cd $XT_ORIG_WORKDIR")
-        self.append_dir(cmds, "/var/log/compute", True)
+        #self.append(cmds, "cd $XT_ORIG_WORKDIR")
+        #self.append_dir(cmds, "/var/log/compute", True)
         #self.append_dir(cmds, "logs", True)
 
         # these are empty for ITP jobs
@@ -1239,7 +1237,7 @@ class BackendBase(implements(BackendInterface)):
 
     # API call
     def read_log_file(self, service_node_info, log_name, start_offset=0, end_offset=None, 
-        encoding='utf-8', use_best_log=True):
+        encoding='utf-8', use_best_log=True, log_source=None):
         pass
 
     # API call
