@@ -70,15 +70,20 @@ def capture_before_files_zip(store, source_dir, ws_name=None, run_name=None, ext
             use_compress = (zip_before=="compress")
             file_helper.zip_up_filenames(fn_zip, filenames, use_compress, remove_prefix_len)
 
+            # redefine our files to be copied
             before_files = [fn_zip]
             omit_files = []
 
-            if service_type == "batch":
-                # add a copy of bootstrap files in parallel to the .zip file so they are available when we start to run on BATCH node
+            if service_type in ["batch", "itp", "aml"]:
+                # add a copy of bootstrap files in parallel to the .zip file so they are available when we start to run
                 # bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_INNER_SH, constants.FN_INNER_BAT, 
                 #     constants.FN_EV, constants.PY_RUN_CONTROLLER, constants.FN_MULTI_RUN_CONTEXT]
-                bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_INNER_SH, \
-                    constants.FN_INNER_BAT, constants.FN_EV, constants.FN_BATCH_HELPER]      
+                if service_type == "batch":
+                    bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_INNER_SH, \
+                        constants.FN_INNER_BAT, constants.FN_EV, constants.FN_BATCH_HELPER]      
+                else:
+                    bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_EV, 
+                        constants.PY_RUN_CONTROLLER, constants.FN_MULTI_RUN_CONTEXT, constants.FN_AML_SHIM]      
 
                 for bs in bootstrap_files:
                     fn_bs = source_dir + "/" + bs
