@@ -30,6 +30,7 @@ from xtlib import pc_utils
 from xtlib import scriptor
 from xtlib import constants
 from xtlib import file_utils
+from xtlib import job_helper
 from xtlib import process_utils
 from xtlib import box_information
 
@@ -171,7 +172,7 @@ class CmdCore():
         job_info = json.loads(text)
         runs_by_box = job_info["runs_by_box"]
 
-        return runs_by_boxes
+        return runs_by_box
 
     def cancel_runs_by_boxes(self, runs_by_box):
         cancel_results_by_boxes = {}
@@ -183,6 +184,7 @@ class CmdCore():
                 if utils.is_azure_batch_box(box_name):
                     job_id, service, node_index = box_name.split("-")
                     azure_batch = AzureBatch(core=self)
+                    ws_name = run_datas[0]["ws_name"]
                     cancel_results, _ = azure_batch.cancel_job_node(self.store, ws_name, job_id, node_index, run_datas)
                 else:
                     # connect to specified box
@@ -240,21 +242,15 @@ class CmdCore():
 
         return node_context
         
+    def compute_run_indexes_for_node(self, total_run_count, node_count, node_index):
+        runs_per_node = math.ceil(total_run_count/node_count)
+        runs_last_node = total_run_count - (runs_per_node * (node_count-1))
+        node_run_count = runs_per_node if node_index < node_count-1 else runs_last_node
 
-    def create_context_file(self, run_data_list, node_index, job_id, tmp_dir, using_hp,  
-        app_info, exper_name, args):
-        ''' create a "node context" JSON file describing all of the runs we need to do for the 
-        current node.  the xt controller will use this file to queue up all of the
-        runs when it starts.
-        '''
-        node_context = self.create_context_file_data(run_data_list, node_index, job_id, using_hp, app_info, exper_name, args)
-        
-        fn_context = tmp_dir + "/" + constants.FN_MULTI_RUN_CONTEXT 
-        text = json.dumps(node_context, indent=4)
-        with open(fn_context, "wt") as tfile:
-            tfile.write(text)
+        first_run_index = runs_per_node*node_index
+        last_run_index = first_run_index + node_run_count - 1
 
-        return fn_context, run_names
+        return first_run_index, last_run_index
 
     def get_client_context(self, exper_name, run_name, app_info, box_info, job_id, node_index, run_specs, resume_name=None, 
             using_hp=False, repeat=None, args=None):
@@ -268,22 +264,19 @@ class CmdCore():
 
         context = Bag()
 
-        # transfer the set of properties
-        context.update_job_stats = self.config.get("mongo", "update-job-stats")
-        context.update_run_stats = self.config.get("mongo", "update-run-stats")
-        context.add_log_records = self.config.get("mongo", "add-log-records")
-        context.use_simple_scheduling = self.config.get("mongo", "use-simple-scheduling")
-        context.buffer_metrics = self.config.get("mongo", "buffer-metrics")
+        # DATABASE options
+        context.database = self.config.get("database")
 
         # simple scheduling
         total_run_count = args["total_run_count"]
         node_count = args["node_count"]
-        runs_per_node = math.ceil(total_run_count/node_count)
-        runs_last_node = total_run_count - (runs_per_node * (node_count-1))
-        node_run_count = runs_per_node if node_index < node_count-1 else runs_last_node
 
-        context.first_run_index = runs_per_node*node_index
-        context.last_run_index = context.first_run_index + node_run_count - 1
+        first_run_index, last_run_index = \
+            self.compute_run_indexes_for_node(total_run_count, node_count, node_index)
+
+        context.first_run_index = first_run_index
+        context.last_run_index = last_run_index
+        context.max_delay = args["max_run_delay"]
 
         context.ws = workspace
         context.working_dir = working_dir
@@ -349,6 +342,7 @@ class CmdCore():
         context.total_run_count = args["total_run_count"]
         context.search_style = args["search_style"]
         context.is_parent = context.search_style != "single"
+        context.create_time = utils.get_arrow_time_str()
 
         # HPARAM search
         hp_config = args["hp_config"]
@@ -377,16 +371,18 @@ class CmdCore():
         context.store_creds = store_creds
         context.store_code_path = config.get_storage_provider_code_path(store_creds)
 
-        mongo_creds, mongo_name = self.config.get_mongo_creds()
+        db_creds = self.config.get_database_creds()
 
         ss_info = self.config.get_store_info()
         storage_tracking = utils.safe_value(ss_info, "track-storage")
 
         if storage_tracking:
-            # no mongo is available for run to use (everything is logged to storage)
-            context.mongo_conn_str = ""
+            # no database is available for run to use (everything is logged to storage)
+            context.db_creds = None
         else:
-            context.mongo_conn_str = mongo_creds["mongo-connection-string"]
+            context.db_creds = db_creds
+
+        context.db_options = self.config.get("database")
 
         context.shell_launch_prefix = box_info.shell_launch_prefix
         
@@ -550,7 +546,7 @@ class CmdCore():
 
         return [fn_context, fn_script]
 
-    def adjust_box_runs_for_controller(self, node_id, box_runs):
+    def adjust_box_runs_for_controller(self, node_index, box_runs):
         first_box_run = box_runs[0]
         box_info = first_box_run["box_info"]
 
@@ -570,7 +566,7 @@ class CmdCore():
 
         # create a single run_data that will run the controller for this node
         run_data = {"box_info": box_info, "box_name": box_info.box_name, "repeat": repeat_count, "run_name": run_name, 
-            "box_secret": first_box_run["box_secret"], "run_specs": run_specs}
+            "box_secret": first_box_run["box_secret"], "run_specs": run_specs, "node_index": node_index}
         new_box_runs = [run_data]
 
         return new_box_runs
@@ -608,7 +604,7 @@ class CmdCore():
             create helper for backend compute service (pool, philly, batch, aml)
         '''
         if not compute_def:
-            compute_def = dict(self.config.get_compute_def(compute))
+            compute_def = dict(self.config.get_target_def(compute))
 
         if not username:
             # not specified as an option; default to config file
