@@ -10,7 +10,7 @@ here, check to see if you need to also change it in psm.py.
 '''
 
 #Sync the BUILD string changes with: setup.py, CHANGELOG.md
-BUILD = "version: 0.0.237, build: Jan-29-2021"
+BUILD = "version: 0.0.240, build: Apr-01-2021"
     
 INFO_CONTAINER_V1 = "xt-store-info"
 INFO_CONTAINER_V2 = "00-store-info"
@@ -20,6 +20,7 @@ STORAGE_FORMAT_V1 = "1"
 INFO_DIR = "__info__"
 STORAGE_INFO_FILE = INFO_DIR + "/storage_info.json"
 NODE_PREFIX = "_"
+FACTORY_CONFIG = "factory_config.yaml"
 
 TRACEBACK = "Traceback (most recent call last)"
 
