@@ -99,11 +99,11 @@ def read_text_file(fn, as_lines=False):
         text = text.split("\n")
     return text
 
-def write_text_file(fn, text, newline=None):
+def write_text_file(fn, text, newline=None, open_mode="w"):
     fn = os.path.expanduser(fn)
     ensure_dir_exists(file=fn)
     
-    with open(fn, "w", newline=newline) as tfile:
+    with open(fn, open_mode, newline=newline) as tfile:
         tfile.write(text)
 
 def split_dirname_basename(path):
@@ -299,7 +299,7 @@ def make_tmp_dir(prefix, fixed_name=True):
 
     return tmp_dir
 
-def fix_slashes(fn, is_linux=None):
+def fix_slashes(fn, is_linux=None, protect_ws_run_name=True):
     # cannot expand here - we don't know if it is local
     #fn = os.path.expanduser(fn)
 
@@ -310,7 +310,7 @@ def fix_slashes(fn, is_linux=None):
         fn = fn.replace("\\", "/")
         console.detail("fixed slashes for linux: {}".format(fn))
     else:
-        if "/run" in fn:
+        if protect_ws_run_name and "/run" in fn:
             # protect ws/runxxx entries which are legal XT cmds
             fn = fn.replace("/run", "$$run")
             fn = fn.replace("/", "\\")
