@@ -267,6 +267,7 @@ class ImplCompute(ImplBase):
         display_count = 0
         started = time.time()
         last_status_shown = None
+        log_source = None
         request_dict = {"t": "predict_train", "e": "predict_eval", "?": "show_hparams", "=": "set_hparam", "h": "help"}
 
         try:
@@ -318,7 +319,7 @@ class ImplCompute(ImplBase):
                     if sleep_count == sleeps_per_call:
 
                         # time to read the log file
-                        result = backend.read_log_file(service_node_info, log_name=log_name, start_offset=start_offset)
+                        result = backend.read_log_file(service_node_info, log_name=log_name, start_offset=start_offset, log_source=log_source)
 
                         new_text = result["new_text"]
                         new_simple = result["simple_status"]
@@ -326,6 +327,7 @@ class ImplCompute(ImplBase):
                         start_offset = result["next_offset"]
                         new_log = result["log_name"]
                         file_path = utils.safe_value(result, "file_path")
+                        log_source = utils.safe_value(result, "log_source")
 
                         if first_call or new_log != log_name:
                             log_name = new_log                
