@@ -16,28 +16,36 @@ from xtlib import file_utils
 from xtlib.storage.store import Store
 from .console import console
 from .helpers import xt_config
-from xtlib.xt_vault import get_store_and_mongo_creds_on_compute_node
+from xtlib.xt_vault import get_store_and_db_creds_on_compute_node
 
 class StoreOnDemand(object):
     '''
     used to delay actual store object for as long as possible
     '''
-    def __init__(self, impl_shared):
-        self.impl_shared = impl_shared
+    def __init__(self, config=None):
+        console.diag("creating StoreOnDemand....")
+        self.config = config
         self.actual_store = None
 
+    def set_config(self, config):
+        self.config = config
+
     def __getattr__(self, name):
         # someone is requesting access to a property or method of our store wrapper object
         # time to create the real Store
+
+        # a simple assignment of a StoreOnDemand, for some reason, triggers an attempt to retreive the "__iter__" attribute
+        # so we catch it here explictly to avoid creating the store too soon
+        if name == "__iter__":
+            raise Exception("Not implemented")
+
+        console.diag("__getattr__: name=", name)
         if not self.actual_store:
-            self.actual_store = self.impl_shared.build_actual_store()
+            self.actual_store = self.build_actual_store()
 
-        return getattr(self.actual_store, name)
-
-class ImplShared():
-    def __init__(self):
-        self.config = None
-        self.store = StoreOnDemand(self)
+        value = getattr(self.actual_store, name)
+        console.diag("returning StoreOnDemand property value={}".format(value))
+        return value
 
     def build_actual_store(self):
         '''
@@ -50,42 +58,60 @@ class ImplShared():
         '''
 
         console.diag("start of build_actual_store")
-        mongo_options = None
         
-        # validate USERNAME
-        username = self.config.get("general", "username", suppress_warning=True)
-        if not username:
-            errors.config_error("'username' must be set in the [general] section of XT config file")
+        db_options = None
 
         # compute node creds take prioity
-        storage_creds, mongo_creds = get_store_and_mongo_creds_on_compute_node()
+        storage_creds, db_creds = get_store_and_db_creds_on_compute_node()
         if storage_creds:
             # running on COMPUTE NODE
             run_cache_dir = None
-            mongo_conn_str = mongo_creds["key"]
+            #db_conn_str = db_creds["key"]
             provider_code_path = os.getenv("XT_STORE_CODE_PATH")
+
             storage_creds["provider"] = provider_code_path.split(".")[2]
             max_log_workers = 0
+            console.diag("compute_node detected, storage_creds=", storage_creds)
+            console.diag("db_creds=", db_creds)
 
+            # since we don't have a config file on the compute node, try to load our context from the MRC file
+            context = utils.load_context_from_mrc()
+            if context:
+                db_options = context.db_options
         else:
-            # running on XT CLIENT machine; get them from config files
+            # running on XT CLIENT machine; get them from config file
+
+            # validate USERNAME as part of config validation
+            username = self.config.get("general", "username", suppress_warning=True)
+            if not username:
+                errors.config_error("'username' must be set in the [general] section of XT config file")
+
             storage_creds = self.config.get_storage_creds()
-            mongo_creds, mongo_name = self.config.get_mongo_creds()
+            db_creds = self.config.get_database_creds()
             run_cache_dir = self.config.get("general", "run-cache-dir")
             provider_code_path = self.config.get_storage_provider_code_path(storage_creds)
 
-            mongo_options = self.config.get("mongo")
+            db_type = db_creds["type"]
+            db_options = self.config.get("database")
 
             #store_key = storage_creds["key"]
-            mongo_conn_str = mongo_creds["mongo-connection-string"]
+            db_conn_str = db_creds["connection-string"]
+            console.diag("db_creds=", db_creds)
+            console.diag("xt client detected, storage_creds=", storage_creds)
 
         self.store = Store(storage_creds, provider_code_path=provider_code_path, run_cache_dir=run_cache_dir, 
-            mongo_conn_str=mongo_conn_str, mongo_options=mongo_options)
+            db_creds=db_creds, db_options=db_options)
 
         console.diag("end of build_actual_store")
 
         return self.store
 
+
+class ImplShared():
+    def __init__(self):
+        self.config = None
+        self.store = StoreOnDemand()
+
     def expand_xt_symbols(self, args):
         for i, arg in enumerate(args):
             
@@ -103,6 +129,7 @@ class ImplShared():
 
     def init_config(self, fn_local_config, args=None):
         self.config = xt_config.get_merged_config(local_overrides_path=fn_local_config)
+        self.store.set_config(self.config)
         return self.config
 
     def pre_dispatch_processing(self, dispatch_type, caller, arg_dict):
