@@ -590,11 +590,7 @@ class ReportBuilder():
         sd, exponent = text.split("e")
         exponent = int(exponent)
 
-        if exponent < 0:
-            needed = 1 - exponent
-        else:
-            needed = 0
-
+        needed = max(0, significance - (exponent+1))
         return needed
 
     def smart_float_format(self, value, significance, max_precision, max_fixed_length):
@@ -689,58 +685,66 @@ class ReportBuilder():
                     # not all columns are defined in all records
                     continue
 
-                value = record[col]
+                try:
+                    value = record[col]
 
-                # special formatting for time values
-                if col in duration_col_names:
-                    value = self.format_duration(value, col, record)
-                elif col in time_col_names:
-                    if isinstance(value, str):
-                        value = arrow.get(value)
-                    value = value.format('YYYY-MM-DD @HH:mm:ss')
+                    # special formatting for time values
+                    if col in duration_col_names:
+                        value = self.format_duration(value, col, record)
+                    elif col in time_col_names:
+                        if isinstance(value, str):
+                            value = arrow.get(value)
+                        value = value.format('YYYY-MM-DD @HH:mm:ss')
 
-                if user_fmt:
-                    # user provided explict format for this column
-                    if "$" in user_fmt:
-                        value_str = self.xt_custom_format(user_fmt, value)
+                    # for sql, convert float types that are really integer values to int types
+                    if isinstance(value, float) and value == int(value) and user_fmt is None and value_type is str:
+                        value = int(value)
+
+                    if user_fmt:
+                        # user provided explict format for this column
+                        if "$" in user_fmt:
+                            value_str = self.xt_custom_format(user_fmt, value)
+                        else:
+                            value_str = user_fmt.format(value)
+                    elif isinstance(value, float):
+
+                        # default (smart) FLOAT formatting
+                        needed = self.needed_precision(value, significance)
+                        max_precision = max(max_precision, needed)
+                        value_str = self.smart_float_format(value, significance, max_precision, max_fixed_length)
+                        
+                        if (value_type == str or value_type is int) and user_fmt is None:
+                            value_type = float
+                            is_numeric = True
+
+                    elif isinstance(value, bool):
+                        value_str = str(value)
+                        value_type = bool
+                        is_numeric = False
+                    elif isinstance(value, int):
+                        value_str = int_fmt.format(value)
+                        if value_type == str:
+                            value_type = int
+                            is_numeric = True
+                    elif value is not None:
+                        # don't let None values influence the type of field
+                        # assume value found is string-like
+                        
+                        # ensure value is a string
+                        value = str(value)
+
+                        value_str = str_fmt.format(value) if value else ""
+                        if first_value:
+                            is_numeric = utils.str_is_float(value)
                     else:
-                        value_str = user_fmt.format(value)
-                elif isinstance(value, float):
+                        value_str = ""
 
-                    # default (smart) FLOAT formatting
-                    needed = self.needed_precision(value, significance)
-                    max_precision = max(max_precision, needed)
-                    value_str = self.smart_float_format(value, significance, max_precision, max_fixed_length)
-                    
-                    if value_type == str:
-                        value_type = float
-                        is_numeric = True
-
-                elif isinstance(value, bool):
-                    value_str = str(value)
-                    value_type = bool
-                    is_numeric = False
-                elif isinstance(value, int):
-                    value_str = int_fmt.format(value)
-                    if value_type == str:
-                        value_type = int
-                        is_numeric = True
-                elif value is not None:
-                    # don't let None values influence the type of field
-                    # assume value found is string-like
-                    
-                    # ensure value is a string
-                    value = str(value)
-
-                    value_str = str_fmt.format(value) if value else ""
-                    if first_value:
-                        is_numeric = utils.str_is_float(value)
-                else:
-                    value_str = ""
-
-                # set width as max of all column values seen so far
-                col_width = max(col_width, len(value_str))
-                #console.print("name=", record["name"], ", col=", col, ", value_str=", value_str, ", col_width=", col_width)
+                    # set width as max of all column values seen so far
+                    col_width = max(col_width, len(value_str))
+                    #console.print("name=", record["name"], ", col=", col, ", value_str=", value_str, ", col_width=", col_width)
+                except BaseException as ex:
+                    console.print("Exception formatting col={}: {}".format(col, ex))
+                    console.print("  Exception record: {}".format(record))
 
             # finish this col
             if is_numeric and not max_precision:
@@ -915,77 +919,88 @@ class ReportBuilder():
             if row_num % 500 == 0:
                 console.diag("build_formatted_table: processing row: {}".format(row_num))
 
-            for col_info in col_infos:
-                if first_col:
-                    first_col = False
-                else:
-                    text += " " * col_space
-
-                user_fmt = col_info["user_fmt"] 
-                col = col_info["name"]
-
-                right_align = right_align_num_cols and (col_info["is_numeric"] or user_fmt or \
-                    col_info["value_type"] == bool) or col in duration_col_names
-
-                col_width = col_info["col_width"]
-                align = ">" if right_align else "<"
-
-                if not col in record:
-                    # not all records define all columns
-                    str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
-                    text += str_fmt.format("")
-                else:
-                    value = record[col]
-
-                    #console.print("col=", col, ", value=", value, ", type(value)=", type(value))
-
-                    # special formatting for time values
-                    if col in duration_col_names:
-                        value = self.format_duration(value, col, record)
-                    elif col in time_col_names:
-                        if isinstance(value, str):
-                            value = arrow.get(value)
-                        value = value.format('YYYY-MM-DD @HH:mm:ss')
-
-                    if user_fmt:
-                        # user provided explict format for this column
-                        if "$" in user_fmt:
-                            # custom XT formatting
-                            value = self.xt_custom_format(user_fmt, value)
-                        else:
-                            value = user_fmt.format(value)   
-
-                        # now treat as string that must fit into col_width
-                        str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
-                        #value = value if value else ""
-                        value = "" if value is None else value
-                        text += str_fmt.format(value)
-                    elif isinstance(value, float):
-
-                        # default (smart) FLOAT formatting
-                        precision = col_info["precision"] if "precision" in col_info else float_precision
-                        if precision >= max_fixed_length:
-                            # use SCIENTIFIC NOTATION
-                            float_fmt = "{:" + align + str(col_width) + "." + str(significance-1) + "e}"
-                        else:
-                            # use FIXED POINT formatting
-                            float_fmt = "{:" + align + str(col_width) + "." + str(precision) + "f}"
-
-                        text += float_fmt.format(value)
-
-                    elif isinstance(value, bool):
-                        bool_fmt = "{!r:" + align + str(col_width) + "}"
-                        text += bool_fmt.format(value)
-                    elif isinstance(value, int):
-                        int_fmt = "{:" + align + str(col_width) + "d}"
-                        text += int_fmt.format(value)
+            col = None
+            try:
+                for col_info in col_infos:
+                    if first_col:
+                        first_col = False
                     else:
-                        if col == "sku":
-                            dummy = 3
-                        # ensure value is a string
-                        value = "" if value is None else str(value)
+                        text += " " * col_space
+
+                    user_fmt = col_info["user_fmt"] 
+                    col = col_info["name"]
+                    value_type = col_info["value_type"]
+
+                    right_align = right_align_num_cols and (col_info["is_numeric"] or user_fmt or \
+                        col_info["value_type"] == bool) or col in duration_col_names
+
+                    col_width = col_info["col_width"]
+                    align = ">" if right_align else "<"
+
+                    if not col in record:
+                        # not all records define all columns
                         str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
-                        text += str_fmt.format(value)
+                        text += str_fmt.format("")
+                    else:
+                        value = record[col]
+
+                        # special handling for int values that were logged as floats
+                        if isinstance(value, float) and value_type is int:
+                            value = int(value)
+
+                        #console.print("col=", col, ", value=", value, ", type(value)=", type(value))
+
+                        # special formatting for time values
+                        if col in duration_col_names:
+                            value = self.format_duration(value, col, record)
+                        elif col in time_col_names:
+                            if isinstance(value, str):
+                                value = arrow.get(value)
+                            value = value.format('YYYY-MM-DD @HH:mm:ss')
+
+                        if user_fmt:
+                            # user provided explict format for this column
+                            if "$" in user_fmt:
+                                # custom XT formatting
+                                value = self.xt_custom_format(user_fmt, value)
+                            else:
+                                value = user_fmt.format(value)   
+
+                            # now treat as string that must fit into col_width
+                            str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
+                            #value = value if value else ""
+                            value = "" if value is None else value
+                            text += str_fmt.format(value)
+                        elif isinstance(value, float):
+
+                            # default (smart) FLOAT formatting
+                            precision = col_info["precision"] if "precision" in col_info else float_precision
+                            if precision > max_fixed_length:
+                                # use SCIENTIFIC NOTATION
+                                float_fmt = "{:" + align + str(col_width) + "." + str(significance-1) + "e}"
+                            else:
+                                # use FIXED POINT formatting
+                                float_fmt = "{:" + align + str(col_width) + "." + str(precision) + "f}"
+
+                            text += float_fmt.format(value)
+
+                        elif isinstance(value, bool):
+                            bool_fmt = "{!r:" + align + str(col_width) + "}"
+                            text += bool_fmt.format(value)
+                        elif isinstance(value, int):
+                            int_fmt = "{:" + align + str(col_width) + "d}"
+                            text += int_fmt.format(value)
+                        else:
+                            if col == "sku":
+                                dummy = 3
+                            # ensure value is a string
+                            value = "" if value is None else str(value)
+                            str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
+                            text += str_fmt.format(value)
+
+            except BaseException as ex:
+                console.print("Exception formatting col={}: {}".format(col, ex))
+                console.print("  Exception record: {}".format(record))
 
             if highlighted:
                 text += pc_utils.NORMAL
