@@ -182,79 +182,85 @@ def remove_run_stats(dd: dict):
 
     return run_stats
 
+user_to_actual = {"box": "box_name", "created": "create_time", "child": "is_child", "cluster": "cluster",
+    "description": "description", "experiment": "exper_name", "exit_code": "exit_code", 
+    "from_host": "from_computer_name", "from_ip": "from_ip", 
+    "guid": "run_guid", "job": "job_id", "last_time": "last_time",
+    "node": "node_index", "outer": "is_outer", "parent": "is_parent", "path": "path", 
+    "pool": "pool", "repeat": "repeat", "restarts": "restarts", "run": "run_name", "run_index": "run_index", 
+    "run_num": "run_num", "script": "script", "search": "search_type", "search_style": "search_style", 
+    "service_type": "service_type", "sku": "sku", "started": "start_time", "status": "status", "target": "compute", 
+    "username": "username", "vc": "vc", "workspace": "ws_name", "xt_build": "xt_build", 
+    "xt_version": "xt_version", "cluster": "cluster", "vc": "vc", "service_run_id": "service_run_id",
+
+    # embedded properties
+    "hparams": "hparams", "metrics": "metrics", "tags": "tags",
+
+    # run stats
+    "ended": "end_time", "started": "start_time", "duration": "run_duration", "queued": "queue_duration",
+    "db_retries": "db_retries", "storage_retries": "storage_retries",
+
+        # special info (not a simple property)
+        "metric_names": "metric_names",
+    }
+
+std_cols_desc = {
+    #"app": "the application associated with the run",
+    "box": "the name of the box the run executed on",
+    "child": "indicates that this run is a child run",
+    "created": "the time when the run was created", 
+    "cluster": "the name of the service cluster for the run", 
+    "ended": "when the run execution ended",
+    "db_retries": "the total number of database retries performed by the runs of this node",
+    "description": "the user specified description associated with the run",
+    "duration": "how long the run has been executing",
+    "ended": "when the run completed",
+    "experiment": "the name of the experiment associated with the run",
+    "exit_code": "the integer value returned by the run",
+    "from_host": "the name of the computer that submitted the run",
+    "from_ip": "the IP address of the computer that submitted the run",
+    "guid": "a string that uniquely identifies the run",
+    "job": "the job id that the run was part of",
+    "last_time": "the time of the most recent operation associated with the run",
+    "metric_names": "list of metrics names, ordered by their reporting",
+    "node": "the 0-based node index of the run's box",
+    "outer": "indicates this run is not a child run",
+    "parent": "indicates that the run spawned child runs",
+    "path": "the full path of the run's target script or executable file",
+    "pool": "the user-defined name describing the backend service or set of boxes on which the run executed",
+    "queued": "how long the run was waiting to start",
+    "repeat": "the user-specified repeat-count for the run",
+    "restarts": "the number of times the run was preempted and restarted",
+    "run": "the name of the run",
+    "run_index": "the job command index assigned to this run",
+    "run_num": "the sort-compatible number portion of run",
+    "script": "the base name of the run's script or executable file",
+    "search": "the type of hyperparameter search used to start the run",
+    "search_style": "describes how search is being accomplished (one of: static, dynamic, multi, repeat, single)",
+    "service_type": "the type of service of the compute target",
+    "service_run_id": "the run id assigned by the backend service",
+    "sku": "the name of the service SKU (machine size) specified for the run",
+    "started": "when the run started executing",
+    "status": "the current status of the run",
+    "storage_retries": "the total number of storage retries performed by the runs of this node",
+    "target": "the compute target the run was submitted to",
+    "username": "the login name of the user who submitted the run",
+    "vc": "the name of the virtual cluster for the run",
+    "workspace": "the name of the workspace containing the run",
+    "xt_build": "the build date of xt that was used to launch the run",
+    "xt_version": "the version of xt that was used to launch the run",
+    }
+
 def get_run_property_dicts():
     # user-friendly property names for jobs
-    user_to_actual = {"box": "box_name", "created": "create_time", "child": "is_child", "cluster": "cluster",
-        "description": "description", "experiment": "exper_name", "exit_code": "exit_code", 
-        "from_host": "from_computer_name", "from_ip": "from_ip", 
-        "guid": "run_guid", "job": "job_id", "last_time": "last_time",
-        "node": "node_index", "outer": "is_outer", "parent": "is_parent", "path": "path", 
-        "pool": "pool", "repeat": "repeat", "restarts": "restarts", "run": "run_name", "run_index": "run_index", 
-        "run_num": "run_num", "script": "script", "search": "search_type", "search_style": "search_style", 
-        "service_type": "service_type", "sku": "sku", "started": "start_time", "status": "status", "target": "compute", 
-        "username": "username", "vc": "vc", "workspace": "ws_name", "xt_build": "xt_build", 
-        "xt_version": "xt_version", "cluster": "cluster", "vc": "vc", "service_run_id": "service_run_id",
-
-        # embedded properties
-        "hparams": "hparams", "metrics": "metrics", "tags": "tags",
-
-        # run stats
-        "ended": "end_time", "started": "start_time", "duration": "run_duration", "queued": "queue_duration",
-        "db_retries": "db_retries", "storage_retries": "storage_retries",
-
-         # special info (not a simple property)
-         "metric_names": "metric_names",
-        }
-
-    std_cols_desc = {
-        #"app": "the application associated with the run",
-        "box": "the name of the box the run executed on",
-        "child": "indicates that this run is a child run",
-        "created": "the time when the run was created", 
-        "cluster": "the name of the service cluster for the run", 
-        "ended": "when the run execution ended",
-        "db_retries": "the total number of database retries performed by the runs of this node",
-        "description": "the user specified description associated with the run",
-        "duration": "how long the run has been executing",
-        "ended": "when the run completed",
-        "experiment": "the name of the experiment associated with the run",
-        "exit_code": "the integer value returned by the run",
-        "from_host": "the name of the computer that submitted the run",
-        "from_ip": "the IP address of the computer that submitted the run",
-        "guid": "a string that uniquely identifies the run",
-        "job": "the job id that the run was part of",
-        "last_time": "the time of the most recent operation associated with the run",
-        "metric_names": "list of metrics names, ordered by their reporting",
-        "node": "the 0-based node index of the run's box",
-        "outer": "indicates this run is not a child run",
-        "parent": "indicates that the run spawned child runs",
-        "path": "the full path of the run's target script or executable file",
-        "pool": "the user-defined name describing the backend service or set of boxes on which the run executed",
-        "queued": "how long the run was waiting to start",
-        "repeat": "the user-specified repeat-count for the run",
-        "restarts": "the number of times the run was preempted and restarted",
-        "run": "the name of the run",
-        "run_index": "the job command index assigned to this run",
-        "run_num": "the sort-compatible number portion of run",
-        "script": "the base name of the run's script or executable file",
-        "search": "the type of hyperparameter search used to start the run",
-        "search_style": "describes how search is being accomplished (one of: static, dynamic, multi, repeat, single)",
-        "service_type": "the type of service of the compute target",
-        "service_run_id": "the run id assigned by the backend service",
-        "sku": "the name of the service SKU (machine size) specified for the run",
-        "started": "when the run started executing",
-        "status": "the current status of the run",
-        "storage_retries": "the total number of storage retries performed by the runs of this node",
-        "target": "the compute target the run was submitted to",
-        "username": "the login name of the user who submitted the run",
-        "vc": "the name of the virtual cluster for the run",
-        "workspace": "the name of the workspace containing the run",
-        "xt_build": "the build date of xt that was used to launch the run",
-        "xt_version": "the version of xt that was used to launch the run",
-        }
 
     return user_to_actual, std_cols_desc
         
+def get_run_property_internal_name(name):
+    if name in user_to_actual:
+        return user_to_actual[name]
+    return None
+
 def build_filter_from_mixed_run_list(store, ws_name, run_list, fd):
 
     exper_names = []
@@ -334,6 +340,10 @@ def build_run_filter_dict(store, ws_name, run_list, user_to_actual, builder, arg
 
     explict_options = qfe.get_explicit_options()
 
+    # # parent is an exception - its default=0 needs to be filtered on
+    # if "parent" not in explict_options:
+    #     explict_options["parent"] = args["parent"]
+
     if run_list:
         build_filter_from_mixed_run_list(store, ws_name, run_list, fd)
 
@@ -1047,6 +1057,9 @@ def wrapup_runs_for_nodes(store, ws_name, job_id, nodes, max_workers):
     else:
         fb.feedback("no runs needing wrapup found")
 
+    # finally, mark the job as CANCELLED
+    store.database.set_job_status(ws_name, job_id, "cancelled")
+
     fb.feedback("done", is_final=True)
 
 def wrapup_run_with_context(store, run, context_dict):
